==> ejc-bfyjerp-api-3.0.0-20241118.092151-40-sources.jar: com/ejianc/business/invest/vo/ProjectDebtVO.java <==
package com.ejianc.business.invest.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 项目投资-项目借款
 * 
 * @author generator
 * 
 */
public class ProjectDebtVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billCode; // 单据编号
    private Integer billState; // 单据状态：0-自由态，1-已提交，2-审批中，3-审批通过，4-审批不通过
    private Long orgId; // 组织
    private String orgCode; // 组织编码
    private String orgName; // 组织名称
    private Long parentOrgId; // 项目所属组织
    private String parentOrgCode; // 项目所属组织编码
    private String parentOrgName; // 项目所属组织名称
    private Long projectId; // 项目id
    private String projectCode; // 项目编码
    private String projectName; // 项目名称
    private BigDecimal projectReceiveMny; // 项目回款
    private Long businessManagerId; // 业务经理
    private String businessManagerName; // 业务经理名称
    private BigDecimal managerDebtMny; // 业务经理名下项目借款
    private String projectBaseInfo; // 项目基本信息
    private String debtInfo; // 借款事由
    private BigDecimal debtMny; // 借款金额
    private String debtMnyStr; // 借款金额大写
    private String interestType; // 计息方式：1-按月计息，2-按天计息，3-不收利息
    private BigDecimal interestRate; // 按天计息为固定值，千分之一；按月计息时，下拉选则，1分，2分，3分，即每月1%，2%，3%利息；不收利息：按0计算
    private String interestRateMonth; // 利率（按月计息），下拉选则，1-1分，2-2分，3-3分，即每月1%，2%，3%利息。
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date interestStartDate; // 利息开始日期
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date interestEndDate; // 预计还款日期
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date handleDate; // 办理日期
    private BigDecimal totalDebtMny; // 累计借款金额（不含本次）
    private BigDecimal totalRepaymentMny; // 累计还款金额
    private BigDecimal totalDebtResidueMny; // 累计借款结余（累计借款本金-累计还款本金）
    private Long accountId; // 收款账户
    private String accountName; // 账户名
    private String memo; // 备注
    private Long employeeId; // 经办人
    private String employeeName; // 经办人名称
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    private Date confirmTime; // 经办时间

    private String debtPerson; // 借款人
    private String incomePerson; // 实际收款人


    //报表用字段
    private Date newInterestEndDate; // 最新还款日期
    private BigDecimal repaymentCapitalMny; // 还款本金（元）
    private BigDecimal repaymentInterestMny; // 利息（元）
    private BigDecimal totalResidueMny; // 剩余未还本金（元）

    private String billStateName; // 单据状态名称

    public String getBillStateName() {
        return billStateName;
    }

    public void setBillStateName(String billStateName) {
        this.billStateName = billStateName;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    @ReferSerialTransfer(referCode = "bfyj-market-project")
    public Long getProjectId() {
        return projectId;
    }

    @ReferDeserialTransfer
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public BigDecimal getProjectReceiveMny() {
        return projectReceiveMny;
    }

    public void setProjectReceiveMny(BigDecimal projectReceiveMny) {
        this.projectReceiveMny = projectReceiveMny;
    }
    public Long getBusinessManagerId() {
        return businessManagerId;
    }

    public void setBusinessManagerId(Long businessManagerId) {
        this.businessManagerId = businessManagerId;
    }
    public String getBusinessManagerName() {
        return businessManagerName;
    }

    public void setBusinessManagerName(String businessManagerName) {
        this.businessManagerName = businessManagerName;
    }
    public BigDecimal getManagerDebtMny() {
        return managerDebtMny;
    }

    public void setManagerDebtMny(BigDecimal managerDebtMny) {
        this.managerDebtMny = managerDebtMny;
    }
    public String getProjectBaseInfo() {
        return projectBaseInfo;
    }

    public void setProjectBaseInfo(String projectBaseInfo) {
        this.projectBaseInfo = projectBaseInfo;
    }
    public String getDebtInfo() {
        return debtInfo;
    }

    public void setDebtInfo(String debtInfo) {
        this.debtInfo = debtInfo;
    }
    public BigDecimal getDebtMny() {
        return debtMny;
    }

    public void setDebtMny(BigDecimal debtMny) {
        this.debtMny = debtMny;
    }
    public String getDebtMnyStr() {
        return debtMnyStr;
    }

    public void setDebtMnyStr(String debtMnyStr) {
        this.debtMnyStr = debtMnyStr;
    }
    public String getInterestType() {
        return interestType;
    }

    public void setInterestType(String interestType) {
        this.interestType = interestType;
    }
    public BigDecimal getInterestRate() {
        return interestRate;
    }

    public void setInterestRate(BigDecimal interestRate) {
        this.interestRate = interestRate;
    }
    public String getInterestRateMonth() {
        return interestRateMonth;
    }

    public void setInterestRateMonth(String interestRateMonth) {
        this.interestRateMonth = interestRateMonth;
    }
    public Date getInterestStartDate() {
        return interestStartDate;
    }

    public void setInterestStartDate(Date interestStartDate) {
        this.interestStartDate = interestStartDate;
    }
    public Date getInterestEndDate() {
        return interestEndDate;
    }

    public void setInterestEndDate(Date interestEndDate) {
        this.interestEndDate = interestEndDate;
    }
    public Date getHandleDate() {
        return handleDate;
    }

    public void setHandleDate(Date handleDate) {
        this.handleDate = handleDate;
    }
    public BigDecimal getTotalDebtMny() {
        return totalDebtMny;
    }

    public void setTotalDebtMny(BigDecimal totalDebtMny) {
        this.totalDebtMny = totalDebtMny;
    }
    public BigDecimal getTotalRepaymentMny() {
        return totalRepaymentMny;
    }

    public void setTotalRepaymentMny(BigDecimal totalRepaymentMny) {
        this.totalRepaymentMny = totalRepaymentMny;
    }
    public BigDecimal getTotalDebtResidueMny() {
        return totalDebtResidueMny;
    }

    public void setTotalDebtResidueMny(BigDecimal totalDebtResidueMny) {
        this.totalDebtResidueMny = totalDebtResidueMny;
    }
    @ReferSerialTransfer(referCode = "finance-bank-acct")
    public Long getAccountId() {
        return accountId;
    }

    @ReferDeserialTransfer
    public void setAccountId(Long accountId) {
        this.accountId = accountId;
    }
    public String getAccountName() {
        return accountName;
    }

    public void setAccountName(String accountName) {
        this.accountName = accountName;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    @ReferSerialTransfer(referCode = "idm-employee")
    public Long getEmployeeId() {
        return employeeId;
    }

    @ReferDeserialTransfer
    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Date getConfirmTime() {
        return confirmTime;
    }

    public void setConfirmTime(Date confirmTime) {
        this.confirmTime = confirmTime;
    }

    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }

    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }

    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }

    public String getDebtPerson() {
        return debtPerson;
    }

    public void setDebtPerson(String debtPerson) {
        this.debtPerson = debtPerson;
    }

    public String getIncomePerson() {
        return incomePerson;
    }

    public void setIncomePerson(String incomePerson) {
        this.incomePerson = incomePerson;
    }

    public Date getNewInterestEndDate() {
        return newInterestEndDate;
    }

    public void setNewInterestEndDate(Date newInterestEndDate) {
        this.newInterestEndDate = newInterestEndDate;
    }

    public BigDecimal getRepaymentCapitalMny() {
        return repaymentCapitalMny;
    }

    public void setRepaymentCapitalMny(BigDecimal repaymentCapitalMny) {
        this.repaymentCapitalMny = repaymentCapitalMny;
    }

    public BigDecimal getRepaymentInterestMny() {
        return repaymentInterestMny;
    }

    public void setRepaymentInterestMny(BigDecimal repaymentInterestMny) {
        this.repaymentInterestMny = repaymentInterestMny;
    }

    public BigDecimal getTotalResidueMny() {
        return totalResidueMny;
    }

    public void setTotalResidueMny(BigDecimal totalResidueMny) {
        this.totalResidueMny = totalResidueMny;
    }
}

==> ejc-bfyjerp-api-3.0.0-20241219.082206-79-sources.jar: com/ejianc/business/invest/vo/ProjectDebtVO.java <==
package com.ejianc.business.invest.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 项目投资-项目借款
 * 
 * @author generator
 * 
 */
public class ProjectDebtVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billCode; // 单据编号
    private Integer billState; // 单据状态：0-自由态，1-已提交，2-审批中，3-审批通过，4-审批不通过
    private Long orgId; // 组织
    private String orgCode; // 组织编码
    private String orgName; // 组织名称
    private Long parentOrgId; // 项目所属组织
    private String parentOrgCode; // 项目所属组织编码
    private String parentOrgName; // 项目所属组织名称
    private Long projectId; // 项目id
    private String projectCode; // 项目编码
    private String projectName; // 项目名称
    private BigDecimal projectReceiveMny; // 项目回款
    private Long businessManagerId; // 业务经理
    private String businessManagerName; // 业务经理名称
    private BigDecimal managerDebtMny; // 业务经理名下项目借款
    private String projectBaseInfo; // 项目基本信息
    private String debtInfo; // 借款事由
    private BigDecimal debtMny; // 借款金额
    private String debtMnyStr; // 借款金额大写
    private String interestType; // 计息方式：1-按月计息，2-按天计息，3-不收利息
    private BigDecimal interestRate; // 按天计息为固定值，千分之一；按月计息时，下拉选则，1分，2分，3分，即每月1%，2%，3%利息；不收利息：按0计算
    private String interestRateMonth; // 利率（按月计息），下拉选则，1-1分，2-2分，3-3分，即每月1%，2%，3%利息。
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date interestStartDate; // 利息开始日期
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date interestEndDate; // 预计还款日期
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date handleDate; // 办理日期
    private BigDecimal totalDebtMny; // 累计借款金额（不含本次）
    private BigDecimal totalRepaymentMny; // 累计还款金额
    private BigDecimal totalDebtResidueMny; // 累计借款结余（累计借款本金-累计还款本金）
    private Long accountId; // 收款账户
    private String accountName; // 账户名
    private String memo; // 备注
    private Long employeeId; // 经办人
    private String employeeName; // 经办人名称
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    private Date confirmTime; // 经办时间

    private String debtPerson; // 借款人
    private String incomePerson; // 实际收款人


    //报表用字段
    private Date newInterestEndDate; // 最新还款日期
    private BigDecimal repaymentCapitalMny; // 还款本金（元）
    private BigDecimal repaymentInterestMny; // 利息（元）
    private BigDecimal totalResidueMny; // 剩余未还本金（元）

    private String billStateName; // 单据状态名称

    public String getBillStateName() {
        return billStateName;
    }

    public void setBillStateName(String billStateName) {
        this.billStateName = billStateName;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    @ReferSerialTransfer(referCode = "bfyj-market-project")
    public Long getProjectId() {
        return projectId;
    }

    @ReferDeserialTransfer
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public BigDecimal getProjectReceiveMny() {
        return projectReceiveMny;
    }

    public void setProjectReceiveMny(BigDecimal projectReceiveMny) {
        this.projectReceiveMny = projectReceiveMny;
    }
    public Long getBusinessManagerId() {
        return businessManagerId;
    }

    public void setBusinessManagerId(Long businessManagerId) {
        this.businessManagerId = businessManagerId;
    }
    public String getBusinessManagerName() {
        return businessManagerName;
    }

    public void setBusinessManagerName(String businessManagerName) {
        this.businessManagerName = businessManagerName;
    }
    public BigDecimal getManagerDebtMny() {
        return managerDebtMny;
    }

    public void setManagerDebtMny(BigDecimal managerDebtMny) {
        this.managerDebtMny = managerDebtMny;
    }
    public String getProjectBaseInfo() {
        return projectBaseInfo;
    }

    public void setProjectBaseInfo(String projectBaseInfo) {
        this.projectBaseInfo = projectBaseInfo;
    }
    public String getDebtInfo() {
        return debtInfo;
    }

    public void setDebtInfo(String debtInfo) {
        this.debtInfo = debtInfo;
    }
    public BigDecimal getDebtMny() {
        return debtMny;
    }

    public void setDebtMny(BigDecimal debtMny) {
        this.debtMny = debtMny;
    }
    public String getDebtMnyStr() {
        return debtMnyStr;
    }

    public void setDebtMnyStr(String debtMnyStr) {
        this.debtMnyStr = debtMnyStr;
    }
    public String getInterestType() {
        return interestType;
    }

    public void setInterestType(String interestType) {
        this.interestType = interestType;
    }
    public BigDecimal getInterestRate() {
        return interestRate;
    }

    public void setInterestRate(BigDecimal interestRate) {
        this.interestRate = interestRate;
    }
    public String getInterestRateMonth() {
        return interestRateMonth;
    }

    public void setInterestRateMonth(String interestRateMonth) {
        this.interestRateMonth = interestRateMonth;
    }
    public Date getInterestStartDate() {
        return interestStartDate;
    }

    public void setInterestStartDate(Date interestStartDate) {
        this.interestStartDate = interestStartDate;
    }
    public Date getInterestEndDate() {
        return interestEndDate;
    }

    public void setInterestEndDate(Date interestEndDate) {
        this.interestEndDate = interestEndDate;
    }
    public Date getHandleDate() {
        return handleDate;
    }

    public void setHandleDate(Date handleDate) {
        this.handleDate = handleDate;
    }
    public BigDecimal getTotalDebtMny() {
        return totalDebtMny;
    }

    public void setTotalDebtMny(BigDecimal totalDebtMny) {
        this.totalDebtMny = totalDebtMny;
    }
    public BigDecimal getTotalRepaymentMny() {
        return totalRepaymentMny;
    }

    public void setTotalRepaymentMny(BigDecimal totalRepaymentMny) {
        this.totalRepaymentMny = totalRepaymentMny;
    }
    public BigDecimal getTotalDebtResidueMny() {
        return totalDebtResidueMny;
    }

    public void setTotalDebtResidueMny(BigDecimal totalDebtResidueMny) {
        this.totalDebtResidueMny = totalDebtResidueMny;
    }
    @ReferSerialTransfer(referCode = "bfyj-account-register")
    public Long getAccountId() {
        return accountId;
    }

    @ReferDeserialTransfer
    public void setAccountId(Long accountId) {
        this.accountId = accountId;
    }
    public String getAccountName() {
        return accountName;
    }

    public void setAccountName(String accountName) {
        this.accountName = accountName;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    @ReferSerialTransfer(referCode = "idm-employee")
    public Long getEmployeeId() {
        return employeeId;
    }

    @ReferDeserialTransfer
    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Date getConfirmTime() {
        return confirmTime;
    }

    public void setConfirmTime(Date confirmTime) {
        this.confirmTime = confirmTime;
    }

    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }

    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }

    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }

    public String getDebtPerson() {
        return debtPerson;
    }

    public void setDebtPerson(String debtPerson) {
        this.debtPerson = debtPerson;
    }

    public String getIncomePerson() {
        return incomePerson;
    }

    public void setIncomePerson(String incomePerson) {
        this.incomePerson = incomePerson;
    }

    public Date getNewInterestEndDate() {
        return newInterestEndDate;
    }

    public void setNewInterestEndDate(Date newInterestEndDate) {
        this.newInterestEndDate = newInterestEndDate;
    }

    public BigDecimal getRepaymentCapitalMny() {
        return repaymentCapitalMny;
    }

    public void setRepaymentCapitalMny(BigDecimal repaymentCapitalMny) {
        this.repaymentCapitalMny = repaymentCapitalMny;
    }

    public BigDecimal getRepaymentInterestMny() {
        return repaymentInterestMny;
    }

    public void setRepaymentInterestMny(BigDecimal repaymentInterestMny) {
        this.repaymentInterestMny = repaymentInterestMny;
    }

    public BigDecimal getTotalResidueMny() {
        return totalResidueMny;
    }

    public void setTotalResidueMny(BigDecimal totalResidueMny) {
        this.totalResidueMny = totalResidueMny;
    }
}
